@@ -19,6 +19,15 @@ class Environment(object):
         self.API_BASE_URL = os.environ['API_BASE_URL']
         self.REMOTE_TOKEN = os.environ['REMOTE_TOKEN']
         self.PUBLIC_API_URL = os.environ['PUBLIC_API_URL']
+        self.PUBLIC_API_KEY = os.environ['PUBLIC_API_KEY']
+        self.PUBLIC_API_SECRET_KEY = os.environ['PUBLIC_API_SECRET_KEY']
+
+        self.SMS_TITLE = os.environ['SMS_TITLE']
+        self.SMS_URL = os.environ['SMS_URL']
+        self.SMS_USERCODE = os.environ['SMS_USERCODE']
+        self.SMS_USERNAME = os.environ['SMS_USERNAME']
+        self.SMS_PASSWORD = os.environ['SMS_PASSWORD']
+        self.ORDER_CACHE_DB = os.environ['ORDER_CACHE_DB']
 
     def env(self, key: str, bucket: str = "main"):
         """
